try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},t=(new e.Error).stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cd438362-3a8e-4518-9cae-926564a4fba4",e._sentryDebugIdIdentifier="sentry-dbid-cd438362-3a8e-4518-9cae-926564a4fba4")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=3647,exports.ids=[3647],exports.modules={"./src/commands/about.ts":(e,t,l)=>{l.r(t),l.d(t,{gatherAboutInfo:()=>f,handleAbout:()=>v});var n=l("node:os"),o=l.n(n),s=l("../proto/dist/generated/aiserver/v1/dashboard_pb.js"),a=l("../../node_modules/.pnpm/chalk@5.4.1/node_modules/chalk/source/index.js"),i=l("./src/console-io.ts"),u=l("./src/state/session.ts"),d=l("./src/utils/terminal-environment.ts"),r=function(e,t,l,n){return new(l||(l=Promise))((function(o,s){function a(e){try{u(n.next(e))}catch(e){s(e)}}function i(e){try{u(n.throw(e))}catch(e){s(e)}}function u(e){var t;e.done?o(e.value):(t=e.value,t instanceof l?t:new l((function(e){e(t)}))).then(a,i)}u((n=n.apply(e,t||[])).next())}))};const c=20;function f(e,t,l){return r(this,void 0,void 0,(function*(){var n,a,i,r,c,f,v;const b=null!=="2026.05.09-0afadcc"?"2026.05.09-0afadcc":"unknown",m=t.get(),g=null!==(r=null!==(a=null===(n=m.model)||void 0===n?void 0:n.displayName)&&void 0!==a?a:null===(i=m.model)||void 0===i?void 0:i.modelId)&&void 0!==r?r:"Auto",y=o().platform(),p=o().arch(),h=(0,d.detectTerminalProgram)(),R=(0,d.detectShell)(),q=u.d.getLastRequestId();let I=null,w=null;try{const t=yield e.getAccessToken(),n=yield e.getRefreshToken();if(t&&n){try{I=null!==(c=(yield l.getMe(new s.GetMeRequest({}))).email)&&void 0!==c?c:null}catch(e){}try{w=null!==(v=null===(f=(yield l.getPlanInfo(new s.GetPlanInfoRequest({}))).planInfo)||void 0===f?void 0:f.planName)&&void 0!==v?v:null}catch(e){}}}catch(e){}return{cliVersion:b,model:g,subscriptionTier:w,osPlatform:y,osArch:p,userEmail:I,terminalProgram:h,shell:R,lastRequestId:q}}))}function v(e,t,l){return r(this,arguments,void 0,(function*(e,t,l,n={}){var o,s;const u=null!==(o=n.format)&&void 0!==o?o:"text";let d=0;try{const n=yield f(e,t,l);"json"===u?(0,i.OT)(JSON.stringify(n,null,2)):(0,i.OT)(function(e){var t,l;const n=[{label:"CLI Version",value:e.cliVersion},{label:"Model",value:e.model},{label:"Subscription Tier",value:null!==(t=e.subscriptionTier)&&void 0!==t?t:"Unknown"},{label:"OS",value:`${e.osPlatform} (${e.osArch})`},{label:"Terminal",value:e.terminalProgram},{label:"Shell",value:e.shell}];return e.lastRequestId&&n.push({label:"Last Request ID",value:e.lastRequestId}),n.push({label:"User Email",value:null!==(l=e.userEmail)&&void 0!==l?l:"Not logged in"}),`${a.Ay.bold.cyan("About Cursor CLI")}\n\n${n.map((e=>`${a.Ay.dim(e.label.padEnd(c))}${e.value}`)).join("\n")}`}(n))}catch(e){d=1;const t=String(e&&"object"==typeof e&&"message"in e&&null!==(s=e.message)&&void 0!==s?s:e);"json"===u?(0,i.OT)(JSON.stringify({status:"error",message:`Failed to get about info: ${t}`},null,2)):(0,i.p2)(a.Ay.red(`Failed to get about info: ${t}`))}finally{process.exit(d)}}))}},"./src/state/session.ts":(e,t,l)=>{l.d(t,{d:()=>o});const n=Object.seal({lastRequest:null}),o=Object.seal({get lastRequest(){return n.lastRequest},recordLastRequest(e,t){const l={id:e,timestamp:Date.now(),path:null==t?void 0:t.path};n.lastRequest=l},getLastRequestId(){var e,t;return null!==(t=null===(e=n.lastRequest)||void 0===e?void 0:e.id)&&void 0!==t?t:null},getLastRequest:()=>n.lastRequest,clearLastRequest(){n.lastRequest=null}})}};