try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="28c7fb22-c7fc-410a-8a15-fa531065b0fd",e._sentryDebugIdIdentifier="sentry-dbid-28c7fb22-c7fc-410a-8a15-fa531065b0fd")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=874,exports.ids=[874],exports.modules={"./src/commands/cloud-get.ts":(e,n,t)=>{t.a(e,(async(e,o)=>{try{t.r(n),t.d(n,{handleCloudGet:()=>f});var s=t("../proto/dist/generated/aiserver/v1/background_composer_pb.js"),a=t("./src/api-command-auth.ts"),d=t("./src/client.ts"),i=t("./src/console-io.ts"),r=t("./src/commands/cloud-list.ts"),c=t("./src/commands/format-utils.ts"),l=e([a,r]);[a,r]=l.then?(await l)():l;var u=function(e,n,t,o){return new(t||(t=Promise))((function(s,a){function d(e){try{r(o.next(e))}catch(e){a(e)}}function i(e){try{r(o.throw(e))}catch(e){a(e)}}function r(e){var n;e.done?s(e.value):(n=e.value,n instanceof t?n:new t((function(e){e(n)}))).then(d,i)}r((o=o.apply(e,n||[])).next())}))};function f(e,n){return u(this,void 0,void 0,(function*(){var t,o;const l=e.trim();0===l.length&&(0,i.uQ)(1,"Cloud agent id must be a non-empty string.");try{const{backendUrl:e}=yield(0,a.E)(n.credentialManager,{endpoint:n.endpoint,apiKey:n.apiKey,authToken:n.authToken}),u=(0,d.c3)(n.credentialManager,e,n.configProvider),f=yield u.listBackgroundComposers(new s.D3X({n:1,bcId:l,includeStatus:!0,includeArchived:!0})),g=f.composers[0];g||(0,i.uQ)(1,`Cloud agent not found: ${l}`);const p=(0,r.toJsonComposer)(g);if("UNSPECIFIED"===p.status||g.isArchived||f.didLoadStatus||(0,i.uQ)(1,"Cloud agent status is unavailable in this environment (did_load_status=false)."),"json"===(null!==(t=n.format)&&void 0!==t?t:"json"))return void(0,i.OT)(JSON.stringify(p));const y=[`ID: ${p.bcId}`,`STATUS: ${p.status}`,`NAME: ${p.name||"-"}`,`REPO: ${p.repoUrl||"-"}`,`BRANCH: ${p.branchName||"-"}`,`PR: ${p.prUrl||"-"}`,`CREATED: ${(0,c.fw)(p.createdAtMs)}`,`UPDATED: ${(0,c.fw)(p.updatedAtMs)}`,`SOURCE: ${p.source}`,"ARCHIVED: "+(p.isArchived?"yes":"no"),"KILLED: "+(p.isKilled?"yes":"no"),`MODEL: ${null!==(o=p.modelName)&&void 0!==o?o:"-"}`,`CHANGES: ${(0,r.formatComposerStats)(g)}`];(0,i.OT)(y.join("\n"))}catch(n){(0,i.uQ)(1,`Failed to fetch cloud agent "${e}": ${n instanceof Error?n.message:String(n)}`)}}))}o()}catch(g){o(g)}}))}};