try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},r=(new e.Error).stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b90a8e08-2378-481a-b101-e6622474cc54",e._sentryDebugIdIdentifier="sentry-dbid-b90a8e08-2378-481a-b101-e6622474cc54")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.09-0afadcc"}}catch(e){}}(),exports.id=4212,exports.ids=[4212],exports.modules={"./src/commands/worker-directory.ts":(e,r,o)=>{o.r(r),o.d(r,{createInvalidWorkerDirectoryError:()=>s,resolveWorkerDirectoryPath:()=>d});var t=o("node:fs"),n=o("node:path"),i=o.n(n);function d(e){if(!e)return{isValid:!0,workspacePath:process.cwd()};const r=i().resolve(e);return(0,t.existsSync)(r)?(0,t.statSync)(r).isDirectory()?{isValid:!0,workspacePath:r}:{isValid:!1,workspacePath:r,reason:"not-directory"}:{isValid:!1,workspacePath:r,reason:"does-not-exist"}}function s(e,r){return"does-not-exist"===e?new Error(`Invalid worker directory: does not exist (${r})`):new Error(`Invalid worker directory: path is not a directory (${r})`)}}};